==> Java-Swing-0.03.tar.gz: Java-Swing-0.03/java/PerlAncestorListener.java <==
import javax.swing.event.AncestorListener;
import org.perl.inline.java.*;

public class      PerlAncestorListener
       extends    InlineJavaPerlCaller
       implements AncestorListener
{
    String sender;
    String callbacks;

    public PerlAncestorListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void ancestorAdded(javax.swing.event.AncestorEvent event)  {
        try {
            CallPerl(
                "Java::Swing::AncestorListener",
                "_AncestorListener",
                new Object[] {sender, callbacks, "ancestorAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void ancestorRemoved(javax.swing.event.AncestorEvent event)  {
        try {
            CallPerl(
                "Java::Swing::AncestorListener",
                "_AncestorListener",
                new Object[] {sender, callbacks, "ancestorRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void ancestorMoved(javax.swing.event.AncestorEvent event)  {
        try {
            CallPerl(
                "Java::Swing::AncestorListener",
                "_AncestorListener",
                new Object[] {sender, callbacks, "ancestorMoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.14.tar.gz: Java-Swing-0.14/java/PerlAncestorListener.java <==
import javax.swing.event.AncestorListener;
import org.perl.inline.java.*;

public class      PerlAncestorListener
       extends    InlineJavaPerlCaller
       implements AncestorListener
{
    String sender;
    String callbacks;

    public PerlAncestorListener() throws InlineJavaException { }

    public PerlAncestorListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void ancestorAdded(javax.swing.event.AncestorEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "ancestorAdded", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void ancestorRemoved(javax.swing.event.AncestorEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "ancestorRemoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void ancestorMoved(javax.swing.event.AncestorEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "ancestorMoved", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
